pycocoa.colors.UIColor

Package pycocoa :: Module colors :: Class UIColor |
[frames] | no frames]

# Class UIColor

      object --+
               |
    bases._Type0 --+
                   |
               Color --+
                       |
            _SystemColor --+
                           |
                          UIColor

Dynamic color for User-Interface elements, adaptable to vibrancy and accessibility settings.

Instance Methods
Inherited from `Color`: `__init__`, `copy`, `toCMY3`, `toHSB3`, `toRGB3` Inherited from `bases._Type0`: `__repr__`, `__str__`, `type2strepr` Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__setattr__`, `__sizeof__`, `__subclasshook__`

Properties
Inherited from `_SystemColor`: `n` Inherited from `Color`: `alpha`, `black`, `blue`, `brightness`, `colorSpace`, `cyan`, `green`, `hex`, `hue`, `magenta`, `name`, `nsColor`, `red`, `saturation`, `white`, `yellow` Inherited from `bases._Type0`: `NS`, `NSDelegate` Inherited from `object`: `__class__`